@@ -7,7 +7,7 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/flaps"
-	"github.com/superfly/flyctl/internal/app"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
@@ -45,7 +45,7 @@ func newMachineExec() *cobra.Command {
 
 func runMachineExec(ctx context.Context) (err error) {
 	var (
-		appName   = app.NameFromContext(ctx)
+		appName   = appconfig.NameFromContext(ctx)
 		machineID = flag.FirstArg(ctx)
 		io        = iostreams.FromContext(ctx)
 		config    = config.FromContext(ctx)
